@@ -412,8 +412,8 @@ class Service(Errorable):
         return hash(self.id)
 
 
-class Router(Errorable):
-    """Router class to use within a data source."""
+class BaseNetworkElement(Errorable):
+    """Base class for NetworkElement types to use within a data source."""
     __slots__ = [
         "_id", "_community", "_host", "_name", "_site", "_url", "_site_uuid", "_uuid"
     ]
@@ -437,7 +437,7 @@ class Router(Errorable):
 
     def get_nm(self, system=None):
         """Return network metadata objects for this object."""
-        ref = NetworkMetadataReference('router', self._id, {})
+        ref = NetworkMetadataReference(self.typename, self._id, {})
         if self._host:
             ref.attributes['host'] = self._host
         if self._name:
@@ -467,11 +467,13 @@ class Router(Errorable):
                 self.err(
                     'community', value,
                     TypeError(
-                        "The router 'community' parameter must be of type string."))
+                        f"The {self.typename} 'community' parameter must be of type string."
+                    ))
                 return
             if value == "":
-                self.err('community', value,
-                         "The router 'community' parameter must be non-empty.")
+                self.err(
+                    'community', value,
+                    f"The {self.typename} 'community' parameter must be non-empty.")
                 return
         self._community = str(value) if value is not None else None
 
@@ -499,11 +501,13 @@ class Router(Errorable):
             if not isinstance(value, str):
                 self.err(
                     'name', value,
-                    TypeError("The router 'name' parameter must be of type string."))
+                    TypeError(
+                        f"The {self.typename} 'name' parameter must be of type string.")
+                )
                 return
             if value == "":
                 self.err('name', value,
-                         "The router 'name' parameter must be non-empty.")
+                         f"The {self.typename} 'name' parameter must be non-empty.")
                 return
         self._name = str(value) if value is not None else None
 
@@ -517,11 +521,13 @@ class Router(Errorable):
             if not isinstance(value, str):
                 self.err(
                     'site', value,
-                    TypeError("The router 'site' parameter must be of type string."))
+                    TypeError(
+                        f"The {self.typename} 'site' parameter must be of type string.")
+                )
                 return
             if value == "":
                 self.err('site', value,
-                         "The router 'site' parameter must be non-empty.")
+                         f"The {self.typename} 'site' parameter must be non-empty.")
                 return
         self._site = str(value) if value is not None else None
 
@@ -533,10 +539,12 @@ class Router(Errorable):
     def url(self, value):
         if value is not None:
             if not isinstance(value, str):
-                self.err('url', value, "The router 'url' parameter must be a string.")
+                self.err('url', value,
+                         f"The {self.typename} 'url' parameter must be a string.")
                 return
             if value == "":
-                self.err('url', value, "The router 'url' parameter must be non-empty.")
+                self.err('url', value,
+                         f"The {self.typename} 'url' parameter must be non-empty.")
                 return
         self._url = value if value is not None else None
 
@@ -555,3 +563,13 @@ class Router(Errorable):
 
     def __hash__(self):
         return hash(self.id)
+
+
+class Olt(BaseNetworkElement):
+    """OLT class to use within a data source."""
+    typename = 'olt'
+
+
+class Router(BaseNetworkElement):
+    """Router class to use within a data source."""
+    typename = 'router'
